pub struct Scrollbar { /* private fields */ }Expand description
A scrollbar within a Scrollable.
Implementations
Sourceimpl Scrollbar
impl Scrollbar
Sourcepub fn new() -> Scrollbar
pub fn new() -> Scrollbar
Creates new Scrollbar for use in a Scrollable.
Create a Scrollbar with zero width to allow a Scrollable to scroll without a visible
scroller.
Sourcepub fn width(self, width: impl Into<Pixels>) -> Scrollbar
pub fn width(self, width: impl Into<Pixels>) -> Scrollbar
Sets the scrollbar width of the Scrollbar .
Sourcepub fn margin(self, margin: impl Into<Pixels>) -> Scrollbar
pub fn margin(self, margin: impl Into<Pixels>) -> Scrollbar
Sets the scrollbar margin of the Scrollbar .
Sourcepub fn scroller_width(self, scroller_width: impl Into<Pixels>) -> Scrollbar
pub fn scroller_width(self, scroller_width: impl Into<Pixels>) -> Scrollbar
Sets the scroller width of the Scrollbar .
Sourcepub fn spacing(self, spacing: impl Into<Pixels>) -> Scrollbar
pub fn spacing(self, spacing: impl Into<Pixels>) -> Scrollbar
Sets whether the Scrollbar should be embedded in the Scrollable, using
the given spacing between itself and the contents.
An embedded Scrollbar will always be displayed, will take layout space,
and will not float over the contents.
Sourcepub fn padding(self, padding: impl Into<Pixels>) -> Scrollbar
pub fn padding(self, padding: impl Into<Pixels>) -> Scrollbar
Sets the padding of the Scrollbar.
The padding is added at the top and bottom of the scrollbar (or at the
left and right ends for a horizontal Scrollbar) when it is visible.
Unlike Self::margin and Self::spacing, the padding does not
affect the layout of the Scrollable.