pub struct Viewport {
pub x: Offset,
pub y: Offset,
pub bounds: Rectangle,
pub content: Size,
}Expand description
The current Viewport of the Scrollable.
Fields
x: OffsetThe current X offset, in Offset units.
y: OffsetThe current Y offset, in Offset units.
bounds: RectangleThe bounds of the Scrollable.
content: SizeThe size of the content of the Scrollable.
Implementations
Sourceimpl Viewport
impl Viewport
Sourcepub fn end(&self) -> AbsoluteOffset
pub fn end(&self) -> AbsoluteOffset
Returns the end of the Viewport.
Sourcepub fn slide(self, other: Viewport) -> Viewport
pub fn slide(self, other: Viewport) -> Viewport
Returns a new Viewport aligned with the coordinates of the
given one.
Sourcepub fn distance_to_end(&self) -> Vector
pub fn distance_to_end(&self) -> Vector
Returns the distance from the current scroll position to the end of the content, in pixels, per axis.
This is the amount of content that can still be scrolled into view: it is zero when the content fits, or when the scroll is at the end.
Sourcepub fn absolute_offset(&self) -> AbsoluteOffset
pub fn absolute_offset(&self) -> AbsoluteOffset
Returns the AbsoluteOffset of the current Viewport.
Sourcepub fn absolute_offset_reversed(&self) -> AbsoluteOffset
pub fn absolute_offset_reversed(&self) -> AbsoluteOffset
Returns the AbsoluteOffset of the current Viewport, but with its
alignment reversed.
This method can be useful to switch the alignment of a Scrollable
while maintaining its scrolling position.
Sourcepub fn relative_offset(&self) -> RelativeOffset
pub fn relative_offset(&self) -> RelativeOffset
Returns the RelativeOffset of the current Viewport.